==> deepin-camera_1.0.0.15.orig.tar.xz: deepin-camera-1.0.0.15/src/translations/deepin-camera_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Er wordt een video opgenomen. Weet je zeker dat je het venster wilt sluiten?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Map openen</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Geen</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Map openen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Je bent niet gemachtigd om deze map te gebruiken</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation>Ongeldige map</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Map openen</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Bestandslocatie</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Vastleggen</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Meerdere foto&apos;s maken</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Vastlegvertraging</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Uitvoer</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Uitvoerformaat</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Met Camera kun je foto&apos;s en video&apos;s maken met je camera of webcam.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Bestand is niet opgeslagen</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Opslaan in:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Resolutie-instellingen</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Resolutie:</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation>Foto maken</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Video opnemen</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Stoppen met foto&apos;s maken</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Geen</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Geen webcam aangetroffen</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>De webcam is in gebruik</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Opname stoppen</translation>
    </message>
</context>
</TS>

==> deepin-camera_1.3.5.orig.tar.xz: deepin-camera-1.3.5/src/translations/deepin-camera_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Er wordt een video opgenomen. Weet je zeker dat je het venster wilt sluiten?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Map openen</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Foto</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Andere camera gebruiken</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Map openen</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Afdrukken</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Je bent niet bevoegd om deze map te gebruiken</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Ongeldige map</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Map openen</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Bestandslocatie</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Vastleggen</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Meerdere foto&apos;s maken</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Vastlegvertraging</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Uitvoer</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Uitvoerformaat</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Met Camera kun je foto&apos;s en video&apos;s maken met je camera of webcam.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Bestand is niet opgeslagen</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Opslaan in:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Resolutie-instellingen</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Resolutie:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Foto&apos;s:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Video&apos;s:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Geluidseffecten</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Spiegelmodus</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Zaklamp</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Opname stoppen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Openen</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Afdrukken</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Sneltoetsen tonen</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Stoppen met foto&apos;s maken</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Rechtermuisknopmenu</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Foto maken</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Video opnemen</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Stoppen met foto&apos;s maken</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Geen</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normaal</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Levendig</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Warm</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Koud</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grijswaarden</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>Z-W</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Zaklamp</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Aan</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Uit</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Wachttijd</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filters</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Belichting</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Geen webcam aangetroffen</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>De webcam is in gebruik</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Opname stoppen</translation>
    </message>
</context>
</TS>
